@@ -1,52 +1,38 @@
 from __future__ import division
-
+from __future__ import unicode_literals
 from dali import address
-from dali import device
+from dali.address import Short
+from dali.exceptions import BadDevice
+from dali.exceptions import DeviceAlreadyBound
+from dali.exceptions import DuplicateDevice
+from dali.exceptions import NoFreeAddress
+from dali.exceptions import NotConnected
+from dali.exceptions import ProgramShortAddressFailure
 import dali.gear.general as gear
 import sets
 import time
 
 
-class DuplicateDevice(Exception):
-    """Attempt to add more than one device with the same short address
-    to a bus.
-    """
-    pass
+class Device(object):
+    """Any DALI slave device that has been configured with a short address."""
 
-
-class BadDevice(Exception):
-    """Device with invalid attributes."""
-    pass
-
-
-class DeviceAlreadyBound(Exception):
-    """Attempt to add a device to a bus that is already bound to a
-    different bus.
-    """
-    pass
-
-
-class NotConnected(Exception):
-    """A connection to the DALI bus is required to complete this
-    operation, but the bus is not connected.
-    """
-    pass
-
-
-class NoFreeAddress(Exception):
-    """An unused short address was required but none was available."""
-    pass
-
-
-class ProgramShortAddressFailure(Exception):
-    """A device did not accept programming of its short address."""
-
-    def __init__(self, address):
+    def __init__(self, address, name=None, bus=None):
+        if not isinstance(address, int) or address < 0 or address > 63:
+            raise ValueError("address must be an integer in the range 0..63")
         self.address = address
+        self.address_obj = Short(address)
+        self.bus = None
+        if bus:
+            self.bind(bus)
+
+    def bind(self, bus):
+        """Bind this device object to a particular DALI bus."""
+        bus.add_device(self)
 
 
 class Bus(object):
     """A DALI bus."""
+
     _all_addresses = sets.ImmutableSet(range(64))
 
     def __init__(self, name=None, interface=None):
@@ -57,7 +43,7 @@ class Bus(object):
 
     def get_interface(self):
         if not self._interface:
-            raise NotConnected
+            raise NotConnected()
         return self._interface
 
     def add_device(self, device):
@@ -87,7 +73,7 @@ class Bus(object):
             response = i.send(
                 gear.QueryControlGearPresent(address.Short(sa)))
             if response.value:
-                device.Device(address=sa, bus=self)
+                Device(address=sa, bus=self)
         self._bus_scanned = True
 
     def set_search_addr(self, addr):
@@ -146,9 +132,9 @@ class Bus(object):
                     if r.value is not True:
                         raise ProgramShortAddressFailure(new_addr)
                     i.send(gear.Withdraw())
-                    device.Device(address=new_addr, bus=self)
+                    Device(address=new_addr, bus=self)
                 else:
                     i.send(gear.Terminate())
-                    raise NoFreeAddress
+                    raise NoFreeAddress()
                 low = low + 1
         i.send(gear.Terminate())
